#ifndef _StdLSchema_HeaderFile_
#include <StdLSchema.hxx>
#endif
#ifndef _Storage_StreamUnknownTypeError_HeaderFile_
#include <Storage_StreamUnknownTypeError.hxx>
#endif
#ifndef _TColStd_SequenceOfAsciiString_HeaderFile_
#include <TColStd_SequenceOfAsciiString.hxx>
#endif
#ifndef _StdLSchema_PDF_Data_HeaderFile_
#include <StdLSchema_PDF_Data.hxx>
#endif
#ifndef _StdLSchema_PDF_Attribute_HeaderFile_
#include <StdLSchema_PDF_Attribute.hxx>
#endif
#ifndef _StdLSchema_PDF_TagSource_HeaderFile_
#include <StdLSchema_PDF_TagSource.hxx>
#endif
#ifndef _StdLSchema_PDF_Reference_HeaderFile_
#include <StdLSchema_PDF_Reference.hxx>
#endif
#ifndef _StdLSchema_PDF_HAttributeArray1_HeaderFile_
#include <StdLSchema_PDF_HAttributeArray1.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Name_HeaderFile_
#include <StdLSchema_PDataStd_Name.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Comment_HeaderFile_
#include <StdLSchema_PDataStd_Comment.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Integer_HeaderFile_
#include <StdLSchema_PDataStd_Integer.hxx>
#endif
#ifndef _StdLSchema_PDataStd_IntegerArray_HeaderFile_
#include <StdLSchema_PDataStd_IntegerArray.hxx>
#endif
#ifndef _StdLSchema_PDataStd_IntegerArray_1_HeaderFile_
#include <StdLSchema_PDataStd_IntegerArray_1.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Real_HeaderFile_
#include <StdLSchema_PDataStd_Real.hxx>
#endif
#ifndef _StdLSchema_PDataStd_RealArray_HeaderFile_
#include <StdLSchema_PDataStd_RealArray.hxx>
#endif
#ifndef _StdLSchema_PDataStd_RealArray_1_HeaderFile_
#include <StdLSchema_PDataStd_RealArray_1.hxx>
#endif
#ifndef _StdLSchema_PDataStd_ExtStringArray_HeaderFile_
#include <StdLSchema_PDataStd_ExtStringArray.hxx>
#endif
#ifndef _StdLSchema_PDataStd_ExtStringArray_1_HeaderFile_
#include <StdLSchema_PDataStd_ExtStringArray_1.hxx>
#endif
#ifndef _StdLSchema_PDataStd_TreeNode_HeaderFile_
#include <StdLSchema_PDataStd_TreeNode.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Position_HeaderFile_
#include <StdLSchema_PDataStd_Position.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Point_HeaderFile_
#include <StdLSchema_PDataStd_Point.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Axis_HeaderFile_
#include <StdLSchema_PDataStd_Axis.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Plane_HeaderFile_
#include <StdLSchema_PDataStd_Plane.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Geometry_HeaderFile_
#include <StdLSchema_PDataStd_Geometry.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Constraint_HeaderFile_
#include <StdLSchema_PDataStd_Constraint.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Placement_HeaderFile_
#include <StdLSchema_PDataStd_Placement.hxx>
#endif
#ifndef _StdLSchema_PDataStd_PatternStd_HeaderFile_
#include <StdLSchema_PDataStd_PatternStd.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Expression_HeaderFile_
#include <StdLSchema_PDataStd_Expression.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Relation_HeaderFile_
#include <StdLSchema_PDataStd_Relation.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Variable_HeaderFile_
#include <StdLSchema_PDataStd_Variable.hxx>
#endif
#ifndef _StdLSchema_PDataStd_NoteBook_HeaderFile_
#include <StdLSchema_PDataStd_NoteBook.hxx>
#endif
#ifndef _StdLSchema_PDataStd_UAttribute_HeaderFile_
#include <StdLSchema_PDataStd_UAttribute.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Directory_HeaderFile_
#include <StdLSchema_PDataStd_Directory.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Shape_HeaderFile_
#include <StdLSchema_PDataStd_Shape.hxx>
#endif
#ifndef _StdLSchema_PDataStd_Tick_HeaderFile_
#include <StdLSchema_PDataStd_Tick.hxx>
#endif
#ifndef _StdLSchema_PDataStd_IntegerList_HeaderFile_
#include <StdLSchema_PDataStd_IntegerList.hxx>
#endif
#ifndef _StdLSchema_PDataStd_RealList_HeaderFile_
#include <StdLSchema_PDataStd_RealList.hxx>
#endif
#ifndef _StdLSchema_PDataStd_ExtStringList_HeaderFile_
#include <StdLSchema_PDataStd_ExtStringList.hxx>
#endif
#ifndef _StdLSchema_PDataStd_BooleanList_HeaderFile_
#include <StdLSchema_PDataStd_BooleanList.hxx>
#endif
#ifndef _StdLSchema_PDataStd_ReferenceList_HeaderFile_
#include <StdLSchema_PDataStd_ReferenceList.hxx>
#endif
#ifndef _StdLSchema_PDataStd_BooleanArray_HeaderFile_
#include <StdLSchema_PDataStd_BooleanArray.hxx>
#endif
#ifndef _StdLSchema_PDataStd_ReferenceArray_HeaderFile_
#include <StdLSchema_PDataStd_ReferenceArray.hxx>
#endif
#ifndef _StdLSchema_PDataStd_ByteArray_HeaderFile_
#include <StdLSchema_PDataStd_ByteArray.hxx>
#endif
#ifndef _StdLSchema_PDataStd_ByteArray_1_HeaderFile_
#include <StdLSchema_PDataStd_ByteArray_1.hxx>
#endif
#ifndef _StdLSchema_PDataStd_NamedData_HeaderFile_
#include <StdLSchema_PDataStd_NamedData.hxx>
#endif
#ifndef _StdLSchema_PDataStd_AsciiString_HeaderFile_
#include <StdLSchema_PDataStd_AsciiString.hxx>
#endif
#ifndef _StdLSchema_PDataStd_IntPackedMap_HeaderFile_
#include <StdLSchema_PDataStd_IntPackedMap.hxx>
#endif
#ifndef _StdLSchema_PDataStd_IntPackedMap_1_HeaderFile_
#include <StdLSchema_PDataStd_IntPackedMap_1.hxx>
#endif
#ifndef _StdLSchema_PDataStd_HArray1OfHAsciiString_HeaderFile_
#include <StdLSchema_PDataStd_HArray1OfHAsciiString.hxx>
#endif
#ifndef _StdLSchema_PDataStd_HArray1OfHArray1OfInteger_HeaderFile_
#include <StdLSchema_PDataStd_HArray1OfHArray1OfInteger.hxx>
#endif
#ifndef _StdLSchema_PDataStd_HArray1OfHArray1OfReal_HeaderFile_
#include <StdLSchema_PDataStd_HArray1OfHArray1OfReal.hxx>
#endif
#ifndef _StdLSchema_PDataStd_HArray1OfByte_HeaderFile_
#include <StdLSchema_PDataStd_HArray1OfByte.hxx>
#endif
#ifndef _StdLSchema_PNaming_Name_HeaderFile_
#include <StdLSchema_PNaming_Name.hxx>
#endif
#ifndef _StdLSchema_PNaming_NamedShape_HeaderFile_
#include <StdLSchema_PNaming_NamedShape.hxx>
#endif
#ifndef _StdLSchema_PNaming_Naming_HeaderFile_
#include <StdLSchema_PNaming_Naming.hxx>
#endif
#ifndef _StdLSchema_PNaming_HArray1OfNamedShape_HeaderFile_
#include <StdLSchema_PNaming_HArray1OfNamedShape.hxx>
#endif
#ifndef _StdLSchema_PDocStd_Document_HeaderFile_
#include <StdLSchema_PDocStd_Document.hxx>
#endif
#ifndef _StdLSchema_PDocStd_XLink_HeaderFile_
#include <StdLSchema_PDocStd_XLink.hxx>
#endif
#ifndef _StdLSchema_PCDM_Document_HeaderFile_
#include <StdLSchema_PCDM_Document.hxx>
#endif
#ifndef _StdLSchema_Standard_Persistent_HeaderFile_
#include <StdLSchema_Standard_Persistent.hxx>
#endif
#ifndef _StdLSchema_PColStd_HArray1OfInteger_HeaderFile_
#include <StdLSchema_PColStd_HArray1OfInteger.hxx>
#endif
#ifndef _StdLSchema_PCollection_HAsciiString_HeaderFile_
#include <StdLSchema_PCollection_HAsciiString.hxx>
#endif
#ifndef _StdLSchema_PCollection_HExtendedString_HeaderFile_
#include <StdLSchema_PCollection_HExtendedString.hxx>
#endif
#ifndef _StdLSchema_PColStd_HArray1OfReal_HeaderFile_
#include <StdLSchema_PColStd_HArray1OfReal.hxx>
#endif
#ifndef _StdLSchema_PColStd_HArray1OfExtendedString_HeaderFile_
#include <StdLSchema_PColStd_HArray1OfExtendedString.hxx>
#endif
#ifndef _StdLSchema_PColStd_HArray2OfInteger_HeaderFile_
#include <StdLSchema_PColStd_HArray2OfInteger.hxx>
#endif
#ifndef _StdLSchema_PTopoDS_HArray1OfShape1_HeaderFile_
#include <StdLSchema_PTopoDS_HArray1OfShape1.hxx>
#endif
#ifndef _StdLSchema_PTopoDS_TShape1_HeaderFile_
#include <StdLSchema_PTopoDS_TShape1.hxx>
#endif
#ifndef _StdLSchema_PTopLoc_Datum3D_HeaderFile_
#include <StdLSchema_PTopLoc_Datum3D.hxx>
#endif
#ifndef _StdLSchema_PTopLoc_ItemLocation_HeaderFile_
#include <StdLSchema_PTopLoc_ItemLocation.hxx>
#endif

Handle_Standard_Type& StdLSchema_Type_()
{

  static Handle_Standard_Type tSchema = STANDARD_TYPE(StdLSchema); 
  static Handle_Standard_Type bSchema = STANDARD_TYPE(Storage_Schema);

  static Handle_Standard_Transient _Ancestors[]= {tSchema,bSchema,NULL};
  static Handle_Standard_Type _aType = new Standard_Type("StdLSchema",
			                                 sizeof(StdLSchema),
			                                 1,
			                                 (Standard_Address)_Ancestors,
			                                 (Standard_Address)NULL);

  return _aType;
}


 Storage_BEGIN_ADD_TYPES(StdLSchema)
 Storage_ADD_TYPES(StdLSchema,PDF_Data,StdLSchema_PDF_Data)
 Storage_ADD_TYPES(StdLSchema,PDF_Attribute,StdLSchema_PDF_Attribute)
 Storage_ADD_TYPES(StdLSchema,PDF_TagSource,StdLSchema_PDF_TagSource)
 Storage_ADD_TYPES(StdLSchema,PDF_Reference,StdLSchema_PDF_Reference)
 Storage_ADD_TYPES(StdLSchema,PDF_HAttributeArray1,StdLSchema_PDF_HAttributeArray1)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Name,StdLSchema_PDataStd_Name)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Comment,StdLSchema_PDataStd_Comment)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Integer,StdLSchema_PDataStd_Integer)
 Storage_ADD_TYPES(StdLSchema,PDataStd_IntegerArray,StdLSchema_PDataStd_IntegerArray)
 Storage_ADD_TYPES(StdLSchema,PDataStd_IntegerArray_1,StdLSchema_PDataStd_IntegerArray_1)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Real,StdLSchema_PDataStd_Real)
 Storage_ADD_TYPES(StdLSchema,PDataStd_RealArray,StdLSchema_PDataStd_RealArray)
 Storage_ADD_TYPES(StdLSchema,PDataStd_RealArray_1,StdLSchema_PDataStd_RealArray_1)
 Storage_ADD_TYPES(StdLSchema,PDataStd_ExtStringArray,StdLSchema_PDataStd_ExtStringArray)
 Storage_ADD_TYPES(StdLSchema,PDataStd_ExtStringArray_1,StdLSchema_PDataStd_ExtStringArray_1)
 Storage_ADD_TYPES(StdLSchema,PDataStd_TreeNode,StdLSchema_PDataStd_TreeNode)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Position,StdLSchema_PDataStd_Position)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Point,StdLSchema_PDataStd_Point)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Axis,StdLSchema_PDataStd_Axis)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Plane,StdLSchema_PDataStd_Plane)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Geometry,StdLSchema_PDataStd_Geometry)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Constraint,StdLSchema_PDataStd_Constraint)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Placement,StdLSchema_PDataStd_Placement)
 Storage_ADD_TYPES(StdLSchema,PDataStd_PatternStd,StdLSchema_PDataStd_PatternStd)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Expression,StdLSchema_PDataStd_Expression)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Relation,StdLSchema_PDataStd_Relation)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Variable,StdLSchema_PDataStd_Variable)
 Storage_ADD_TYPES(StdLSchema,PDataStd_NoteBook,StdLSchema_PDataStd_NoteBook)
 Storage_ADD_TYPES(StdLSchema,PDataStd_UAttribute,StdLSchema_PDataStd_UAttribute)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Directory,StdLSchema_PDataStd_Directory)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Shape,StdLSchema_PDataStd_Shape)
 Storage_ADD_TYPES(StdLSchema,PDataStd_Tick,StdLSchema_PDataStd_Tick)
 Storage_ADD_TYPES(StdLSchema,PDataStd_IntegerList,StdLSchema_PDataStd_IntegerList)
 Storage_ADD_TYPES(StdLSchema,PDataStd_RealList,StdLSchema_PDataStd_RealList)
 Storage_ADD_TYPES(StdLSchema,PDataStd_ExtStringList,StdLSchema_PDataStd_ExtStringList)
 Storage_ADD_TYPES(StdLSchema,PDataStd_BooleanList,StdLSchema_PDataStd_BooleanList)
 Storage_ADD_TYPES(StdLSchema,PDataStd_ReferenceList,StdLSchema_PDataStd_ReferenceList)
 Storage_ADD_TYPES(StdLSchema,PDataStd_BooleanArray,StdLSchema_PDataStd_BooleanArray)
 Storage_ADD_TYPES(StdLSchema,PDataStd_ReferenceArray,StdLSchema_PDataStd_ReferenceArray)
 Storage_ADD_TYPES(StdLSchema,PDataStd_ByteArray,StdLSchema_PDataStd_ByteArray)
 Storage_ADD_TYPES(StdLSchema,PDataStd_ByteArray_1,StdLSchema_PDataStd_ByteArray_1)
 Storage_ADD_TYPES(StdLSchema,PDataStd_NamedData,StdLSchema_PDataStd_NamedData)
 Storage_ADD_TYPES(StdLSchema,PDataStd_AsciiString,StdLSchema_PDataStd_AsciiString)
 Storage_ADD_TYPES(StdLSchema,PDataStd_IntPackedMap,StdLSchema_PDataStd_IntPackedMap)
 Storage_ADD_TYPES(StdLSchema,PDataStd_IntPackedMap_1,StdLSchema_PDataStd_IntPackedMap_1)
 Storage_ADD_TYPES(StdLSchema,PDataStd_HArray1OfHAsciiString,StdLSchema_PDataStd_HArray1OfHAsciiString)
 Storage_ADD_TYPES(StdLSchema,PDataStd_HArray1OfHArray1OfInteger,StdLSchema_PDataStd_HArray1OfHArray1OfInteger)
 Storage_ADD_TYPES(StdLSchema,PDataStd_HArray1OfHArray1OfReal,StdLSchema_PDataStd_HArray1OfHArray1OfReal)
 Storage_ADD_TYPES(StdLSchema,PDataStd_HArray1OfByte,StdLSchema_PDataStd_HArray1OfByte)
 Storage_ADD_TYPES(StdLSchema,PNaming_Name,StdLSchema_PNaming_Name)
 Storage_ADD_TYPES(StdLSchema,PNaming_NamedShape,StdLSchema_PNaming_NamedShape)
 Storage_ADD_TYPES(StdLSchema,PNaming_Naming,StdLSchema_PNaming_Naming)
 Storage_ADD_TYPES(StdLSchema,PNaming_HArray1OfNamedShape,StdLSchema_PNaming_HArray1OfNamedShape)
 Storage_ADD_TYPES(StdLSchema,PDocStd_Document,StdLSchema_PDocStd_Document)
 Storage_ADD_TYPES(StdLSchema,PDocStd_XLink,StdLSchema_PDocStd_XLink)
 Storage_ADD_TYPES(StdLSchema,PCDM_Document,StdLSchema_PCDM_Document)
 Storage_ADD_TYPES(StdLSchema,Standard_Persistent,StdLSchema_Standard_Persistent)
 Storage_ADD_TYPES(StdLSchema,PColStd_HArray1OfInteger,StdLSchema_PColStd_HArray1OfInteger)
 Storage_ADD_TYPES(StdLSchema,PCollection_HAsciiString,StdLSchema_PCollection_HAsciiString)
 Storage_ADD_TYPES(StdLSchema,PCollection_HExtendedString,StdLSchema_PCollection_HExtendedString)
 Storage_ADD_TYPES(StdLSchema,PColStd_HArray1OfReal,StdLSchema_PColStd_HArray1OfReal)
 Storage_ADD_TYPES(StdLSchema,PColStd_HArray1OfExtendedString,StdLSchema_PColStd_HArray1OfExtendedString)
 Storage_ADD_TYPES(StdLSchema,PColStd_HArray2OfInteger,StdLSchema_PColStd_HArray2OfInteger)
 Storage_ADD_TYPES(StdLSchema,PTopoDS_HArray1OfShape1,StdLSchema_PTopoDS_HArray1OfShape1)
 Storage_ADD_TYPES(StdLSchema,PTopoDS_TShape1,StdLSchema_PTopoDS_TShape1)
 Storage_ADD_TYPES(StdLSchema,PTopLoc_Datum3D,StdLSchema_PTopLoc_Datum3D)
 Storage_ADD_TYPES(StdLSchema,PTopLoc_ItemLocation,StdLSchema_PTopLoc_ItemLocation)
 Storage_END_ADD_TYPES(StdLSchema)


 Storage_BEGIN_READ_SELECTION(StdLSchema)
 Storage_READ_SELECTION(StdLSchema,PDF_Data,StdLSchema_PDF_Data)
 Storage_READ_SELECTION(StdLSchema,PDF_TagSource,StdLSchema_PDF_TagSource)
 Storage_READ_SELECTION(StdLSchema,PDF_Reference,StdLSchema_PDF_Reference)
 Storage_READ_SELECTION(StdLSchema,PDF_HAttributeArray1,StdLSchema_PDF_HAttributeArray1)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Name,StdLSchema_PDataStd_Name)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Comment,StdLSchema_PDataStd_Comment)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Integer,StdLSchema_PDataStd_Integer)
 Storage_READ_SELECTION(StdLSchema,PDataStd_IntegerArray,StdLSchema_PDataStd_IntegerArray)
 Storage_READ_SELECTION(StdLSchema,PDataStd_IntegerArray_1,StdLSchema_PDataStd_IntegerArray_1)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Real,StdLSchema_PDataStd_Real)
 Storage_READ_SELECTION(StdLSchema,PDataStd_RealArray,StdLSchema_PDataStd_RealArray)
 Storage_READ_SELECTION(StdLSchema,PDataStd_RealArray_1,StdLSchema_PDataStd_RealArray_1)
 Storage_READ_SELECTION(StdLSchema,PDataStd_ExtStringArray,StdLSchema_PDataStd_ExtStringArray)
 Storage_READ_SELECTION(StdLSchema,PDataStd_ExtStringArray_1,StdLSchema_PDataStd_ExtStringArray_1)
 Storage_READ_SELECTION(StdLSchema,PDataStd_TreeNode,StdLSchema_PDataStd_TreeNode)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Position,StdLSchema_PDataStd_Position)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Point,StdLSchema_PDataStd_Point)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Axis,StdLSchema_PDataStd_Axis)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Plane,StdLSchema_PDataStd_Plane)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Geometry,StdLSchema_PDataStd_Geometry)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Constraint,StdLSchema_PDataStd_Constraint)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Placement,StdLSchema_PDataStd_Placement)
 Storage_READ_SELECTION(StdLSchema,PDataStd_PatternStd,StdLSchema_PDataStd_PatternStd)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Expression,StdLSchema_PDataStd_Expression)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Relation,StdLSchema_PDataStd_Relation)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Variable,StdLSchema_PDataStd_Variable)
 Storage_READ_SELECTION(StdLSchema,PDataStd_NoteBook,StdLSchema_PDataStd_NoteBook)
 Storage_READ_SELECTION(StdLSchema,PDataStd_UAttribute,StdLSchema_PDataStd_UAttribute)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Directory,StdLSchema_PDataStd_Directory)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Shape,StdLSchema_PDataStd_Shape)
 Storage_READ_SELECTION(StdLSchema,PDataStd_Tick,StdLSchema_PDataStd_Tick)
 Storage_READ_SELECTION(StdLSchema,PDataStd_IntegerList,StdLSchema_PDataStd_IntegerList)
 Storage_READ_SELECTION(StdLSchema,PDataStd_RealList,StdLSchema_PDataStd_RealList)
 Storage_READ_SELECTION(StdLSchema,PDataStd_ExtStringList,StdLSchema_PDataStd_ExtStringList)
 Storage_READ_SELECTION(StdLSchema,PDataStd_BooleanList,StdLSchema_PDataStd_BooleanList)
 Storage_READ_SELECTION(StdLSchema,PDataStd_ReferenceList,StdLSchema_PDataStd_ReferenceList)
 Storage_READ_SELECTION(StdLSchema,PDataStd_BooleanArray,StdLSchema_PDataStd_BooleanArray)
 Storage_READ_SELECTION(StdLSchema,PDataStd_ReferenceArray,StdLSchema_PDataStd_ReferenceArray)
 Storage_READ_SELECTION(StdLSchema,PDataStd_ByteArray,StdLSchema_PDataStd_ByteArray)
 Storage_READ_SELECTION(StdLSchema,PDataStd_ByteArray_1,StdLSchema_PDataStd_ByteArray_1)
 Storage_READ_SELECTION(StdLSchema,PDataStd_NamedData,StdLSchema_PDataStd_NamedData)
 Storage_READ_SELECTION(StdLSchema,PDataStd_AsciiString,StdLSchema_PDataStd_AsciiString)
 Storage_READ_SELECTION(StdLSchema,PDataStd_IntPackedMap,StdLSchema_PDataStd_IntPackedMap)
 Storage_READ_SELECTION(StdLSchema,PDataStd_IntPackedMap_1,StdLSchema_PDataStd_IntPackedMap_1)
 Storage_READ_SELECTION(StdLSchema,PDataStd_HArray1OfHAsciiString,StdLSchema_PDataStd_HArray1OfHAsciiString)
 Storage_READ_SELECTION(StdLSchema,PDataStd_HArray1OfHArray1OfInteger,StdLSchema_PDataStd_HArray1OfHArray1OfInteger)
 Storage_READ_SELECTION(StdLSchema,PDataStd_HArray1OfHArray1OfReal,StdLSchema_PDataStd_HArray1OfHArray1OfReal)
 Storage_READ_SELECTION(StdLSchema,PDataStd_HArray1OfByte,StdLSchema_PDataStd_HArray1OfByte)
 Storage_READ_SELECTION(StdLSchema,PNaming_Name,StdLSchema_PNaming_Name)
 Storage_READ_SELECTION(StdLSchema,PNaming_NamedShape,StdLSchema_PNaming_NamedShape)
 Storage_READ_SELECTION(StdLSchema,PNaming_Naming,StdLSchema_PNaming_Naming)
 Storage_READ_SELECTION(StdLSchema,PNaming_HArray1OfNamedShape,StdLSchema_PNaming_HArray1OfNamedShape)
 Storage_READ_SELECTION(StdLSchema,PDocStd_Document,StdLSchema_PDocStd_Document)
 Storage_READ_SELECTION(StdLSchema,PDocStd_XLink,StdLSchema_PDocStd_XLink)
 Storage_READ_SELECTION(StdLSchema,PColStd_HArray1OfInteger,StdLSchema_PColStd_HArray1OfInteger)
 Storage_READ_SELECTION(StdLSchema,PCollection_HAsciiString,StdLSchema_PCollection_HAsciiString)
 Storage_READ_SELECTION(StdLSchema,PCollection_HExtendedString,StdLSchema_PCollection_HExtendedString)
 Storage_READ_SELECTION(StdLSchema,PColStd_HArray1OfReal,StdLSchema_PColStd_HArray1OfReal)
 Storage_READ_SELECTION(StdLSchema,PColStd_HArray1OfExtendedString,StdLSchema_PColStd_HArray1OfExtendedString)
 Storage_READ_SELECTION(StdLSchema,PColStd_HArray2OfInteger,StdLSchema_PColStd_HArray2OfInteger)
 Storage_READ_SELECTION(StdLSchema,PTopoDS_HArray1OfShape1,StdLSchema_PTopoDS_HArray1OfShape1)
 Storage_READ_SELECTION(StdLSchema,PTopLoc_Datum3D,StdLSchema_PTopLoc_Datum3D)
 Storage_READ_SELECTION(StdLSchema,PTopLoc_ItemLocation,StdLSchema_PTopLoc_ItemLocation)
 Storage_END_READ_SELECTION(StdLSchema)


  Storage_BEGIN_SCHEMA_TYPES(StdLSchema)
  Storage_SCHEMA_TYPES(PDF_Data)
  Storage_SCHEMA_TYPES(PDF_Attribute)
  Storage_SCHEMA_TYPES(PDF_TagSource)
  Storage_SCHEMA_TYPES(PDF_Reference)
  Storage_SCHEMA_TYPES(PDF_HAttributeArray1)
  Storage_SCHEMA_TYPES(PDataStd_Name)
  Storage_SCHEMA_TYPES(PDataStd_Comment)
  Storage_SCHEMA_TYPES(PDataStd_Integer)
  Storage_SCHEMA_TYPES(PDataStd_IntegerArray)
  Storage_SCHEMA_TYPES(PDataStd_IntegerArray_1)
  Storage_SCHEMA_TYPES(PDataStd_Real)
  Storage_SCHEMA_TYPES(PDataStd_RealArray)
  Storage_SCHEMA_TYPES(PDataStd_RealArray_1)
  Storage_SCHEMA_TYPES(PDataStd_ExtStringArray)
  Storage_SCHEMA_TYPES(PDataStd_ExtStringArray_1)
  Storage_SCHEMA_TYPES(PDataStd_TreeNode)
  Storage_SCHEMA_TYPES(PDataStd_Position)
  Storage_SCHEMA_TYPES(PDataStd_Point)
  Storage_SCHEMA_TYPES(PDataStd_Axis)
  Storage_SCHEMA_TYPES(PDataStd_Plane)
  Storage_SCHEMA_TYPES(PDataStd_Geometry)
  Storage_SCHEMA_TYPES(PDataStd_Constraint)
  Storage_SCHEMA_TYPES(PDataStd_Placement)
  Storage_SCHEMA_TYPES(PDataStd_PatternStd)
  Storage_SCHEMA_TYPES(PDataStd_Expression)
  Storage_SCHEMA_TYPES(PDataStd_Relation)
  Storage_SCHEMA_TYPES(PDataStd_Variable)
  Storage_SCHEMA_TYPES(PDataStd_NoteBook)
  Storage_SCHEMA_TYPES(PDataStd_UAttribute)
  Storage_SCHEMA_TYPES(PDataStd_Directory)
  Storage_SCHEMA_TYPES(PDataStd_Shape)
  Storage_SCHEMA_TYPES(PDataStd_Tick)
  Storage_SCHEMA_TYPES(PDataStd_IntegerList)
  Storage_SCHEMA_TYPES(PDataStd_RealList)
  Storage_SCHEMA_TYPES(PDataStd_ExtStringList)
  Storage_SCHEMA_TYPES(PDataStd_BooleanList)
  Storage_SCHEMA_TYPES(PDataStd_ReferenceList)
  Storage_SCHEMA_TYPES(PDataStd_BooleanArray)
  Storage_SCHEMA_TYPES(PDataStd_ReferenceArray)
  Storage_SCHEMA_TYPES(PDataStd_ByteArray)
  Storage_SCHEMA_TYPES(PDataStd_ByteArray_1)
  Storage_SCHEMA_TYPES(PDataStd_NamedData)
  Storage_SCHEMA_TYPES(PDataStd_AsciiString)
  Storage_SCHEMA_TYPES(PDataStd_IntPackedMap)
  Storage_SCHEMA_TYPES(PDataStd_IntPackedMap_1)
  Storage_SCHEMA_TYPES(PDataStd_HArray1OfHAsciiString)
  Storage_SCHEMA_TYPES(PDataStd_HArray1OfHArray1OfInteger)
  Storage_SCHEMA_TYPES(PDataStd_HArray1OfHArray1OfReal)
  Storage_SCHEMA_TYPES(PDataStd_HArray1OfByte)
  Storage_SCHEMA_TYPES(PNaming_Name)
  Storage_SCHEMA_TYPES(PNaming_NamedShape)
  Storage_SCHEMA_TYPES(PNaming_Naming)
  Storage_SCHEMA_TYPES(PNaming_HArray1OfNamedShape)
  Storage_SCHEMA_TYPES(PDocStd_Document)
  Storage_SCHEMA_TYPES(PDocStd_XLink)
  Storage_SCHEMA_TYPES(PCDM_Document)
  Storage_SCHEMA_TYPES(Standard_Persistent)
  Storage_SCHEMA_TYPES(PColStd_HArray1OfInteger)
  Storage_SCHEMA_TYPES(PCollection_HAsciiString)
  Storage_SCHEMA_TYPES(PCollection_HExtendedString)
  Storage_SCHEMA_TYPES(PColStd_HArray1OfReal)
  Storage_SCHEMA_TYPES(PColStd_HArray1OfExtendedString)
  Storage_SCHEMA_TYPES(PColStd_HArray2OfInteger)
  Storage_SCHEMA_TYPES(PTopoDS_HArray1OfShape1)
  Storage_SCHEMA_TYPES(PTopoDS_TShape1)
  Storage_SCHEMA_TYPES(PTopLoc_Datum3D)
  Storage_SCHEMA_TYPES(PTopLoc_ItemLocation)
  Storage_END_SCHEMA_TYPES(StdLSchema)

